[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=ansible_django-ansible-base&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=ansible_django-ansible-base)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=ansible_django-ansible-base&metric=coverage)](https://sonarcloud.io/summary/new_code?id=ansible_django-ansible-base)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=ansible_django-ansible-base&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=ansible_django-ansible-base)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=ansible_django-ansible-base&metric=security_rating)](https://sonarcloud.io/summary/new_code?id=ansible_django-ansible-base)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=ansible_django-ansible-base&metric=bugs)](https://sonarcloud.io/summary/new_code?id=ansible_django-ansible-base)
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=ansible_django-ansible-base&metric=code_smells)](https://sonarcloud.io/summary/new_code?id=ansible_django-ansible-base)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=ansible_django-ansible-base&metric=sqale_rating)](https://sonarcloud.io/summary/new_code?id=ansible_django-ansible-base)

# django-ansible-base

## What is it?
Django-ansible-base is exactly what it says it is. A base for any Ansible application which will leverage Django.

## Documentation

Docs for django-ansible-base features can be found in the [docs](docs) directory.

Information about the test_app and how to start/use it can be found in [test_app/README.md](test_app/README.md)
